package cn.com.infosec.asn1.ocsp;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.ASN1TaggedObject;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERSequence;
import cn.com.infosec.asn1.DERTaggedObject;

public class OCSPRequest extends ASN1Encodable {
   TBSRequest tbsRequest;
   Signature optionalSignature;

   public OCSPRequest(TBSRequest tbsRequest, Signature optionalSignature) {
      this.tbsRequest = tbsRequest;
      this.optionalSignature = optionalSignature;
   }

   public OCSPRequest(ASN1Sequence seq) {
      this.tbsRequest = TBSRequest.getInstance(seq.getObjectAt(0));
      if (seq.size() == 2) {
         this.optionalSignature = Signature.getInstance((ASN1TaggedObject)seq.getObjectAt(1), true);
      }

   }

   public static OCSPRequest getInstance(ASN1TaggedObject obj, boolean explicit) {
      return getInstance(ASN1Sequence.getInstance(obj, explicit));
   }

   public static OCSPRequest getInstance(Object obj) {
      if (obj != null && !(obj instanceof OCSPRequest)) {
         if (obj instanceof ASN1Sequence) {
            return new OCSPRequest((ASN1Sequence)obj);
         } else {
            throw new IllegalArgumentException("unknown object in factory: " + obj.getClass().getName());
         }
      } else {
         return (OCSPRequest)obj;
      }
   }

   public TBSRequest getTbsRequest() {
      return this.tbsRequest;
   }

   public Signature getOptionalSignature() {
      return this.optionalSignature;
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      ASN1EncodableVector var10001 = var1 = new ASN1EncodableVector;
      var1.<init>();
      var10001.add(this.tbsRequest);
      Signature var3;
      if ((var3 = this.optionalSignature) != null) {
         DERTaggedObject var2;
         var2 = new DERTaggedObject.<init>(true, 0, var3);
         var1.add(var2);
      }

      return new DERSequence(var1);
   }
}
